@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+from typing import *
+
 import abc
 import copy
 import dataclasses
@@ -5,7 +9,6 @@ import multiprocessing
 import pickle
 import secrets
 import warnings
-from typing import *
 
 from hippolyzer.lib.base.datatypes import UUID, Vector3
 from hippolyzer.lib.base.message.message import Block, Message
@@ -14,10 +17,11 @@ from hippolyzer.lib.proxy import addon_ctx
 from hippolyzer.lib.proxy.addons import AddonManager
 from hippolyzer.lib.proxy.http_flow import HippoHTTPFlow
 from hippolyzer.lib.base.network.transport import UDPPacket, Direction
-from hippolyzer.lib.proxy.region import ProxiedRegion
-from hippolyzer.lib.proxy.sessions import SessionManager, Session
 from hippolyzer.lib.proxy.task_scheduler import TaskLifeScope
 from hippolyzer.lib.base.templates import ChatSourceType, ChatType
+if TYPE_CHECKING:
+    from hippolyzer.lib.proxy.sessions import SessionManager, Session
+    from hippolyzer.lib.proxy.region import ProxiedRegion
 
 
 class AssetAliasTracker:
@@ -139,7 +143,34 @@ def ais_folder_to_inventory_data(ais_folder: dict):
     )
 
 
-class BaseAddon(abc.ABC):
+class MetaBaseAddon(abc.ABCMeta):
+    """
+    Metaclass for BaseAddon that prevents class member assignments from clobbering descriptors
+
+    Without this things like:
+
+        class Foo(BaseAddon):
+            bar: int = GlobalProperty(0)
+
+        Foo.bar = 2
+
+    Won't work as you expect!
+    """
+    def __setattr__(self, key: str, value):
+        # TODO: Keep track of AddonProperties in __new__ or something?
+        try:
+            existing = object.__getattribute__(self, key)
+        except AttributeError:
+            # If the attribute doesn't exist then it's fine to use the base setattr.
+            super().__setattr__(key, value)
+            return
+        if existing and isinstance(existing, BaseAddonProperty):
+            existing.__set__(self, value)
+            return
+        super().__setattr__(key, value)
+
+
+class BaseAddon(metaclass=MetaBaseAddon):
     def _schedule_task(self, coro: Coroutine, session=None,
                        region_scoped=False, session_scoped=True, addon_scoped=True):
         session = session or addon_ctx.session.get(None) or None
@@ -208,7 +239,7 @@ class BaseAddon(abc.ABC):
 
 
 _T = TypeVar("_T")
-_U = TypeVar("_U", Session, SessionManager)
+_U = TypeVar("_U", "Session", "SessionManager")
 
 
 class BaseAddonProperty(abc.ABC, Generic[_T, _U]):
@@ -257,7 +288,7 @@ class BaseAddonProperty(abc.ABC, Generic[_T, _U]):
         self._get_context_obj().addon_ctx[self.name] = value
 
 
-class SessionProperty(BaseAddonProperty[_T, Session]):
+class SessionProperty(BaseAddonProperty[_T, "Session"]):
     """
     Property tied to the current session context
 
@@ -267,7 +298,7 @@ class SessionProperty(BaseAddonProperty[_T, Session]):
         return addon_ctx.session.get()
 
 
-class GlobalProperty(BaseAddonProperty[_T, SessionManager]):
+class GlobalProperty(BaseAddonProperty[_T, "SessionManager"]):
     """
     Property tied to the global SessionManager context
 
