@@ -58,6 +58,15 @@ class BaseInteractionManager:
         return None
 
 
+# Used to initialize a REPL environment with commonly desired helpers
+REPL_INITIALIZER = r"""
+from hippolyzer.lib.base.datatypes import *
+from hippolyzer.lib.base.templates import *
+from hippolyzer.lib.base.message.message import Block, Message, Direction
+from hippolyzer.lib.proxy.addon_utils import send_chat, show_message
+"""
+
+
 class AddonManager:
     COMMAND_CHANNEL = 524
 
@@ -133,6 +142,16 @@ class AddonManager:
         if _locals is None:
             _locals = stack.frame.f_locals
 
+        init_globals = {}
+        exec(REPL_INITIALIZER, init_globals, None)
+        # We're modifying the globals of the caller, be careful of things we imported
+        # for the REPL initializer clobber things that already exist in the caller's globals.
+        # Making our own mutable copy of the globals dict, mutating that and then passing it
+        # to embed() is not an option due to https://github.com/prompt-toolkit/ptpython/issues/279
+        for global_name, global_val in init_globals.items():
+            if global_name not in _globals:
+                _globals[global_name] = global_val
+
         async def _wrapper():
             coro: Coroutine = ptpython.repl.embed(  # noqa: the type signature lies
                 globals=_globals,
@@ -256,6 +275,9 @@ class AddonManager:
 
         new_addons = {}
         for spec in cls.BASE_ADDON_SPECS[:]:
+            previous_mod = cls.FRESH_ADDON_MODULES.get(spec.name)
+            # Whether we've EVER successfully loaded this module,
+            # There may be a `None` entry in the dict if that's the case.
             had_mod = spec.name in cls.FRESH_ADDON_MODULES
             try:
                 mtime = get_mtime(spec.origin)
@@ -270,20 +292,21 @@ class AddonManager:
                         # Keep module loaded even if file went away.
                         continue
 
+                if previous_mod:
+                    cls._unload_module(previous_mod)
+
                 logging.info("(Re)compiling addon %s" % spec.origin)
-                old_mod = cls.FRESH_ADDON_MODULES.get(spec.name)
                 mod = importlib.util.module_from_spec(spec)
                 sys.modules[spec.name] = mod
                 spec.loader.exec_module(mod)
                 cls.FILE_MTIMES[spec.origin] = mtime
-                cls._unload_module(old_mod)
 
                 new_addons[spec.name] = mod
 
                 # Make sure module initialization happens after any pending task cancellations
                 # due to module unloading.
-
-                asyncio.get_event_loop().call_soon(cls._init_module, mod)
+                loop = asyncio.get_event_loop_policy().get_event_loop()
+                loop.call_soon(cls._init_module, mod)
             except Exception as e:
                 if had_mod:
                     logging.exception("Exploded trying to reload addon %s" % spec.name)
