@@ -11,7 +11,7 @@ from hippolyzer.lib.base.templates import PCode
 from hippolyzer.lib.client.namecache import NameCache
 from hippolyzer.lib.client.object_manager import (
     ClientObjectManager,
-    UpdateType, ClientWorldObjectManager,
+    ObjectUpdateType, ClientWorldObjectManager,
 )
 
 from hippolyzer.lib.base.objects import Object
@@ -63,18 +63,25 @@ class ProxyObjectManager(ClientObjectManager):
             cache_dir=self._region.session().cache_dir,
         )
 
-    def request_missed_cached_objects_soon(self):
+    def request_missed_cached_objects_soon(self, report_only=False):
         if self._cache_miss_timer:
             self._cache_miss_timer.cancel()
         # Basically debounce. Will only trigger 0.2 seconds after the last time it's invoked to
         # deal with the initial flood of ObjectUpdateCached and the natural lag time between that
         # and the viewers' RequestMultipleObjects messages
-        self._cache_miss_timer = asyncio.get_event_loop().call_later(
-            0.2, self._request_missed_cached_objects)
+        loop = asyncio.get_event_loop_policy().get_event_loop()
+        self._cache_miss_timer = loop.call_later(0.2, self._request_missed_cached_objects, report_only)
 
-    def _request_missed_cached_objects(self):
+    def _request_missed_cached_objects(self, report_only: bool):
         self._cache_miss_timer = None
-        self.request_objects(self.queued_cache_misses)
+        if not self.queued_cache_misses:
+            # All the queued cache misses ended up being satisfied without us
+            # having to request them, no need to fire off a request.
+            return
+        if report_only:
+            print(f"Would have automatically requested {self.queued_cache_misses!r}")
+        else:
+            self.request_objects(self.queued_cache_misses)
         self.queued_cache_misses.clear()
 
     def clear(self):
@@ -110,9 +117,12 @@ class ProxyWorldObjectManager(ClientWorldObjectManager):
         )
 
     def _handle_object_update_cached_misses(self, region_handle: int, missing_locals: Set[int]):
+        region_mgr: Optional[ProxyObjectManager] = self._get_region_manager(region_handle)
         if not self._settings.ALLOW_AUTO_REQUEST_OBJECTS:
-            return
-        if self._settings.AUTOMATICALLY_REQUEST_MISSING_OBJECTS:
+            if self._settings.USE_VIEWER_OBJECT_CACHE:
+                region_mgr.queued_cache_misses |= missing_locals
+                region_mgr.request_missed_cached_objects_soon(report_only=True)
+        elif self._settings.AUTOMATICALLY_REQUEST_MISSING_OBJECTS:
             # Schedule these local IDs to be requested soon if the viewer doesn't request
             # them itself. Ideally we could just mutate the CRC of the ObjectUpdateCached
             # to force a CRC cache miss in the viewer, but that appears to cause the viewer
@@ -123,16 +133,16 @@ class ProxyWorldObjectManager(ClientWorldObjectManager):
             region_mgr.queued_cache_misses |= missing_locals
             region_mgr.request_missed_cached_objects_soon()
 
-    def _run_object_update_hooks(self, obj: Object, updated_props: Set[str], update_type: UpdateType):
+    def _run_object_update_hooks(self, obj: Object, updated_props: Set[str], update_type: ObjectUpdateType):
         super()._run_object_update_hooks(obj, updated_props, update_type)
         region = self._session.region_by_handle(obj.RegionHandle)
         if self._settings.ALLOW_AUTO_REQUEST_OBJECTS:
             if obj.PCode == PCode.AVATAR and "ParentID" in updated_props:
                 if obj.ParentID and not region.objects.lookup_localid(obj.ParentID):
                     # If an avatar just sat on an object we don't know about, add it to the queued
-                    # cache misses and request if if the viewer doesn't. This should happen
-                    # regardless of the auto-request object setting because otherwise we have no way
-                    # to get a sitting agent's true region location, even if it's ourself.
+                    # cache misses and request it if the viewer doesn't. This should happen
+                    # regardless of the auto-request missing objects setting because otherwise we
+                    # have no way to get a sitting agent's true region location, even if it's ourselves.
                     region.objects.queued_cache_misses.add(obj.ParentID)
                     region.objects.request_missed_cached_objects_soon()
         AddonManager.handle_object_updated(self._session, region, obj, updated_props)
